prometheus.component


config->metriccljmultimethod

source

ConfigMetricclj

source

default-metricsclj

source

expose-metrics-http-request-handlerclj

(expose-metrics-http-request-handler {headers :headers
                                      {:keys [prometheus config]} :components})

Inputs: [{headers :headers, {:keys [prometheus config]} :components}]

Inputs: [{headers :headers, {:keys [prometheus config]} :components}]
sourceraw docstring

metrics-typesclj

source

MetricTypeclj

source

PrometheusComponentclj

source

report-elapsed-time!cljmacro

(report-elapsed-time! registry id & body)

Measures the elapsed time (msecs) to run the given body of code, reports it as a prometheus metric, and returns the result of the body.

Measures the elapsed time (msecs) to run the given body of code, reports it as a prometheus metric, and returns the result of the body.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries