(expose-metrics-http-request-handler {headers :headers
{:keys [prometheus config]} :components})Inputs: [{headers :headers, {:keys [prometheus config]} :components}]
Inputs: [{headers :headers, {:keys [prometheus config]} :components}]
(report-elapsed-time! registry id & body)Measures the elapsed time (msecs) to run the given body of code, reports it as a prometheus metric, and returns the result of the body.
Measures the elapsed time (msecs) to run the given body of code, reports it as a prometheus metric, and returns the result of the body.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |